# CodegenPipelineComponent

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**image** | **str** |  | [optional] 
**creator** | **str** |  | [optional] 
**version** | **str** |  | [optional] 
**help_link** | **str** |  | [optional] 
**spec** | **str** |  | [optional] 
**sha256** | **str** |  | [optional] 
**created_time** | **datetime** |  | [optional] 
**source_url** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


